# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Attachment(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    mime_type = attr.ib(type=str, default=None, metadata={'json': 'mime_type'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    size = attr.ib(type=int, default=None, metadata={'json': 'size'})


@to_json_decorator
@attr.s
class WorkExperience(object):
    company = attr.ib(type=str, default=None, metadata={'json': 'company'})
    department = attr.ib(type=str, default=None, metadata={'json': 'department'})
    job = attr.ib(type=str, default=None, metadata={'json': 'job'})
    start = attr.ib(type=str, default=None, metadata={'json': 'start'})
    end = attr.ib(type=str, default=None, metadata={'json': 'end'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})


@to_json_decorator
@attr.s
class WorkLocation(object):
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class NativeRegion(object):
    iso_code = attr.ib(type=str, default=None, metadata={'json': 'iso_code'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class Manager(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    en_name = attr.ib(type=str, default=None, metadata={'json': 'en_name'})


@to_json_decorator
@attr.s
class JobLevel(object):
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class Job(object):
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class EmergencyContact(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    relationship = attr.ib(type=int, default=None, metadata={'json': 'relationship'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})


@to_json_decorator
@attr.s
class Education(object):
    level = attr.ib(type=int, default=None, metadata={'json': 'level'})
    school = attr.ib(type=str, default=None, metadata={'json': 'school'})
    major = attr.ib(type=str, default=None, metadata={'json': 'major'})
    degree = attr.ib(type=int, default=None, metadata={'json': 'degree'})
    start = attr.ib(type=str, default=None, metadata={'json': 'start'})
    end = attr.ib(type=str, default=None, metadata={'json': 'end'})


@to_json_decorator
@attr.s
class CustomFields(object):
    key = attr.ib(type=str, default=None, metadata={'json': 'key'})
    label = attr.ib(type=str, default=None, metadata={'json': 'label'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    value = attr.ib(type=str, default=None, metadata={'json': 'value'})


@to_json_decorator
@attr.s
class ContractCompany(object):
    id = attr.ib(type=int, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class SystemFields(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    en_name = attr.ib(type=str, default=None, metadata={'json': 'en_name'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})
    department_id = attr.ib(type=str, default=None, metadata={'json': 'department_id'})
    manager = attr.ib(type=Manager, default=None, metadata={'json': 'manager'})
    job = attr.ib(type=Job, default=None, metadata={'json': 'job'})
    job_level = attr.ib(type=JobLevel, default=None, metadata={'json': 'job_level'})
    work_location = attr.ib(type=WorkLocation, default=None, metadata={'json': 'work_location'})
    gender = attr.ib(type=int, default=None, metadata={'json': 'gender'})
    birthday = attr.ib(type=str, default=None, metadata={'json': 'birthday'})
    native_region = attr.ib(type=NativeRegion, default=None, metadata={'json': 'native_region'})
    ethnicity = attr.ib(type=int, default=None, metadata={'json': 'ethnicity'})
    marital_status = attr.ib(type=int, default=None, metadata={'json': 'marital_status'})
    political_status = attr.ib(type=int, default=None, metadata={'json': 'political_status'})
    entered_workforce_date = attr.ib(type=str, default=None, metadata={'json': 'entered_workforce_date'})
    id_type = attr.ib(type=int, default=None, metadata={'json': 'id_type'})
    id_number = attr.ib(type=str, default=None, metadata={'json': 'id_number'})
    hukou_type = attr.ib(type=int, default=None, metadata={'json': 'hukou_type'})
    hukou_location = attr.ib(type=str, default=None, metadata={'json': 'hukou_location'})
    bank_account_number = attr.ib(type=str, default=None, metadata={'json': 'bank_account_number'})
    bank_name = attr.ib(type=str, default=None, metadata={'json': 'bank_name'})
    social_security_account = attr.ib(type=str, default=None, metadata={'json': 'social_security_account'})
    provident_fund_account = attr.ib(type=str, default=None, metadata={'json': 'provident_fund_account'})
    employee_no = attr.ib(type=str, default=None, metadata={'json': 'employee_no'})
    employee_type = attr.ib(type=int, default=None, metadata={'json': 'employee_type'})
    status = attr.ib(type=int, default=None, metadata={'json': 'status'})
    hire_date = attr.ib(type=str, default=None, metadata={'json': 'hire_date'})
    probation_months = attr.ib(type=float, default=None, metadata={'json': 'probation_months'})
    conversion_date = attr.ib(type=str, default=None, metadata={'json': 'conversion_date'})
    application = attr.ib(type=int, default=None, metadata={'json': 'application'})
    application_status = attr.ib(type=int, default=None, metadata={'json': 'application_status'})
    last_day = attr.ib(type=str, default=None, metadata={'json': 'last_day'})
    departure_type = attr.ib(type=int, default=None, metadata={'json': 'departure_type'})
    departure_reason = attr.ib(type=int, default=None, metadata={'json': 'departure_reason'})
    departure_notes = attr.ib(type=str, default=None, metadata={'json': 'departure_notes'})
    contract_company = attr.ib(type=ContractCompany, default=None, metadata={'json': 'contract_company'})
    contract_type = attr.ib(type=int, default=None, metadata={'json': 'contract_type'})
    contract_start_date = attr.ib(type=str, default=None, metadata={'json': 'contract_start_date'})
    contract_expiration_date = attr.ib(type=str, default=None, metadata={'json': 'contract_expiration_date'})
    contract_sign_times = attr.ib(type=int, default=None, metadata={'json': 'contract_sign_times'})
    personal_email = attr.ib(type=str, default=None, metadata={'json': 'personal_email'})
    family_address = attr.ib(type=str, default=None, metadata={'json': 'family_address'})
    primary_emergency_contact = attr.ib(type=EmergencyContact, default=None, metadata={'json': 'primary_emergency_contact'})
    emergency_contact = attr.ib(type=List[EmergencyContact], default=None, metadata={'json': 'emergency_contact'})
    highest_level_of_edu = attr.ib(type=Education, default=None, metadata={'json': 'highest_level_of_edu'})
    education = attr.ib(type=List[Education], default=None, metadata={'json': 'education'})
    former_work_exp = attr.ib(type=WorkExperience, default=None, metadata={'json': 'former_work_exp'})
    work_exp = attr.ib(type=List[WorkExperience], default=None, metadata={'json': 'work_exp'})
    id_photo_po_side = attr.ib(type=List[Attachment], default=None, metadata={'json': 'id_photo_po_side'})
    id_photo_em_side = attr.ib(type=List[Attachment], default=None, metadata={'json': 'id_photo_em_side'})
    id_photo = attr.ib(type=List[Attachment], default=None, metadata={'json': 'id_photo'})
    diploma_photo = attr.ib(type=List[Attachment], default=None, metadata={'json': 'diploma_photo'})
    graduation_cert = attr.ib(type=List[Attachment], default=None, metadata={'json': 'graduation_cert'})
    cert_of_merit = attr.ib(type=List[Attachment], default=None, metadata={'json': 'cert_of_merit'})
    offboarding_file = attr.ib(type=List[Attachment], default=None, metadata={'json': 'offboarding_file'})
    cancel_onboarding_reason = attr.ib(type=int, default=None, metadata={'json': 'cancel_onboarding_reason'})
    cancel_onboarding_notes = attr.ib(type=str, default=None, metadata={'json': 'cancel_onboarding_notes'})
    employee_form_status = attr.ib(type=int, default=None, metadata={'json': 'employee_form_status'})
    create_time = attr.ib(type=int, default=None, metadata={'json': 'create_time'})
    update_time = attr.ib(type=int, default=None, metadata={'json': 'update_time'})


@to_json_decorator
@attr.s
class Employee(object):
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    system_fields = attr.ib(type=SystemFields, default=None, metadata={'json': 'system_fields'})
    custom_fields = attr.ib(type=List[CustomFields], default=None, metadata={'json': 'custom_fields'})






@attr.s
class EmployeeListResult(object):
    items = attr.ib(type=List[Employee], default=None, metadata={'json': 'items'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})


# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class DocsApi(object):
    pass


@to_json_decorator
@attr.s
class DocsEntity(object):
    docs_token = attr.ib(type=str, default=None, metadata={'json': 'docs_token'})
    docs_type = attr.ib(type=str, default=None, metadata={'json': 'docs_type'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})
    docs_owner = attr.ib(type=str, default=None, metadata={'json': 'docs_owner'})


@to_json_decorator
@attr.s
class DocsMeta(object):
    docs_token = attr.ib(type=str, default=None, metadata={'json': 'docs_token'})
    docs_type = attr.ib(type=str, default=None, metadata={'json': 'docs_type'})
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})
    owner_id = attr.ib(type=str, default=None, metadata={'json': 'owner_id'})
    create_time = attr.ib(type=int, default=None, metadata={'json': 'create_time'})
    latest_modify_user = attr.ib(type=str, default=None, metadata={'json': 'latest_modify_user'})
    latest_modify_time = attr.ib(type=int, default=None, metadata={'json': 'latest_modify_time'})


@to_json_decorator
@attr.s
class RequestDoc(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})



@to_json_decorator
@attr.s
class DocsApiMetaReqBody(object):
    request_docs = attr.ib(type=List[RequestDoc], default=None, metadata={'json': 'request_docs'})


@attr.s
class DocsApiMetaResult(object):
    docs_metas = attr.ib(type=List[DocsMeta], default=None, metadata={'json': 'docs_metas'})


@to_json_decorator
@attr.s
class DocsApiSearchReqBody(object):
    search_key = attr.ib(type=str, default=None, metadata={'json': 'search_key'})
    count = attr.ib(type=int, default=None, metadata={'json': 'count'})
    offset = attr.ib(type=int, default=None, metadata={'json': 'offset'})
    owner_ids = attr.ib(type=List[str], default=None, metadata={'json': 'owner_ids'})
    chat_ids = attr.ib(type=List[str], default=None, metadata={'json': 'chat_ids'})
    docs_types = attr.ib(type=str, default=None, metadata={'json': 'docs_types'})


@attr.s
class DocsApiSearchResult(object):
    docs_entities = attr.ib(type=List[DocsEntity], default=None, metadata={'json': 'docs_entities'})
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    total = attr.ib(type=int, default=None, metadata={'json': 'total'})


# -*- coding: UTF-8 -*-


from typing import Any, Union

from ...model.oapi_request import OapiRequest
from ...model.oapi_response import OapiResponse
import attr


@attr.s
class BaseEvent(object):
    ts = attr.ib(type=str, default='')
    uuid = attr.ib(type=str, default='')
    token = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')


@attr.s
class BaseEventData(object):
    app_id = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')
    tenant_key = attr.ib(type=str, default='')


@attr.s
class Header(object):
    event_id = attr.ib(type=str, default='')
    event_type = attr.ib(type=str, default='')
    app_id = attr.ib(type=str, default='')
    tenant_key = attr.ib(type=str, default='')
    create_time = attr.ib(type=str, default='')
    token = attr.ib(type=str, default='')


@attr.s
class Fuzzy(object):
    schema = attr.ib(type=str, default='')
    token = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')
    challenge = attr.ib(type=str, default='')
    header = attr.ib(type=Header, default=None)
    event = attr.ib(type=BaseEventData, default=None)


@attr.s
class BaseEventV2(object):
    schema = attr.ib(type=str, default='')
    header = attr.ib(type=Header, default=None)


@attr.s
class HTTPEvent(object):
    schema = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')
    event_type = attr.ib(type=str, default='')
    challenge = attr.ib(type=str, default='')
    error = attr.ib(type=Union[None, Exception], default=None)
    request = attr.ib(type=OapiRequest, default=None)
    response = attr.ib(type=OapiResponse, default=None)
    data = attr.ib(type=Union[None, Any], default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr


@to_json_decorator
@attr.s
class Bot(object):
    pass


@to_json_decorator
@attr.s
class BotInfo(object):
    activate_status = attr.ib(type=int, default=None, metadata={'json': 'activate_status'})
    app_name = attr.ib(type=str, default=None, metadata={'json': 'app_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    ip_white_list = attr.ib(type=List[str], default=None, metadata={'json': 'ip_white_list'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})


@attr.s
class BotGetResult(object):
    bot = attr.ib(type=BotInfo, default=None, metadata={'json': 'bot'})



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Authen(object):
    pass


@to_json_decorator
@attr.s
class UserAccessTokenInfo(object):
    access_token = attr.ib(type=str, default=None, metadata={'json': 'access_token'})
    token_type = attr.ib(type=str, default=None, metadata={'json': 'token_type'})
    expires_in = attr.ib(type=int, default=None, metadata={'json': 'expires_in'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    en_name = attr.ib(type=str, default=None, metadata={'json': 'en_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    avatar_thumb = attr.ib(type=str, default=None, metadata={'json': 'avatar_thumb'})
    avatar_middle = attr.ib(type=str, default=None, metadata={'json': 'avatar_middle'})
    avatar_big = attr.ib(type=str, default=None, metadata={'json': 'avatar_big'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    refresh_expires_in = attr.ib(type=int, default=None, metadata={'json': 'refresh_expires_in'})
    refresh_token = attr.ib(type=str, default=None, metadata={'json': 'refresh_token'})


@to_json_decorator
@attr.s
class UserInfo(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    en_name = attr.ib(type=str, default=None, metadata={'json': 'en_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    avatar_thumb = attr.ib(type=str, default=None, metadata={'json': 'avatar_thumb'})
    avatar_middle = attr.ib(type=str, default=None, metadata={'json': 'avatar_middle'})
    avatar_big = attr.ib(type=str, default=None, metadata={'json': 'avatar_big'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})



@to_json_decorator
@attr.s
class AuthenAccessTokenReqBody(object):
    grant_type = attr.ib(type=str, default=None, metadata={'json': 'grant_type'})
    code = attr.ib(type=str, default=None, metadata={'json': 'code'})



@to_json_decorator
@attr.s
class AuthenRefreshAccessTokenReqBody(object):
    grant_type = attr.ib(type=str, default=None, metadata={'json': 'grant_type'})
    refresh_token = attr.ib(type=str, default=None, metadata={'json': 'refresh_token'})





# -*- coding: UTF-8 -*-


from typing import Dict

from ...model.oapi_request import OapiRequest
from ...model.oapi_response import OapiResponse
import attr


@attr.s
class Header(object):
    time_stamp = attr.ib(type=str, default='')
    nonce = attr.ib(type=str, default='')
    signature = attr.ib(type=str, default='')
    refresh_token = attr.ib(type=str, default='')


@attr.s
class Challenge(object):
    challenge = attr.ib(type=str, default='')
    token = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')


@attr.s
class Action(object):
    value = attr.ib(type=Dict, default='')
    tag = attr.ib(type=str, default='')
    option = attr.ib(type=str, default='')
    timezone = attr.ib(type=str, default='')


@attr.s
class Card(object):
    open_id = attr.ib(type=str, default='')
    user_id = attr.ib(type=str, default='')
    open_message_id = attr.ib(type=str, default='')
    tenant_key = attr.ib(type=str, default='')
    token = attr.ib(type=str, default='')
    timezone = attr.ib(type=str, default='')
    action = attr.ib(type=Action, default='')


@attr.s
class HTTPCard(object):
    request = attr.ib(type=OapiRequest, default=None)
    response = attr.ib(type=OapiResponse, default=None)
    challenge = attr.ib(type=str, default='')
    type = attr.ib(type=str, default='')



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Child(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})


@to_json_decorator
@attr.s
class File(object):
    pass


@to_json_decorator
@attr.s
class Folder(object):
    pass


@to_json_decorator
@attr.s
class OperatorId(object):
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    union_id = attr.ib(type=str, default=None, metadata={'json': 'union_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})




@attr.s
class FolderChildrenResult(object):
    parent_token = attr.ib(type=str, default=None, metadata={'json': 'parentToken'})
    children = attr.ib(type=Dict[str, Child], default=None, metadata={'json': 'children'})


@to_json_decorator
@attr.s
class FileCopyReqBody(object):
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    dst_folder_token = attr.ib(type=str, default=None, metadata={'json': 'dstFolderToken'})
    dst_name = attr.ib(type=str, default=None, metadata={'json': 'dstName'})
    comment_needed = attr.ib(type=bool, default=None, metadata={'json': 'commentNeeded'})


@attr.s
class FileCopyResult(object):
    folder_token = attr.ib(type=str, default=None, metadata={'json': 'folderToken'})
    revision = attr.ib(type=int, default=None, metadata={'json': 'revision'})
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})


@to_json_decorator
@attr.s
class FileCreateReqBody(object):
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})


@attr.s
class FileCreateResult(object):
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})
    revision = attr.ib(type=int, default=None, metadata={'json': 'revision'})
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})


@to_json_decorator
@attr.s
class FolderCreateReqBody(object):
    title = attr.ib(type=str, default=None, metadata={'json': 'title'})


@attr.s
class FolderCreateResult(object):
    url = attr.ib(type=str, default=None, metadata={'json': 'url'})
    revision = attr.ib(type=int, default=None, metadata={'json': 'revision'})
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})



@attr.s
class FileDocsDeleteResult(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    result = attr.ib(type=bool, default=None, metadata={'json': 'result'})



@attr.s
class FolderMetaResult(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    create_uid = attr.ib(type=str, default=None, metadata={'json': 'createUid'})
    edit_uid = attr.ib(type=str, default=None, metadata={'json': 'editUid'})
    parent_id = attr.ib(type=str, default=None, metadata={'json': 'parentId'})
    own_uid = attr.ib(type=str, default=None, metadata={'json': 'ownUid'})



@attr.s
class FolderRootMetaResult(object):
    token = attr.ib(type=str, default=None, metadata={'json': 'token'})
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})



@attr.s
class FileSpreadsheetsDeleteResult(object):
    id = attr.ib(type=str, default=None, metadata={'json': 'id'})
    result = attr.ib(type=bool, default=None, metadata={'json': 'result'})


# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import Callable

from ....config import Config
from ....context import Context
from ....event.event import set_event_callback

from .model import *


class MeetingLeaveMeetingEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingLeaveMeetingEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingLeaveMeetingEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingLeaveMeetingEvent], Any]) -> None
        handler = MeetingLeaveMeetingEventHandler(callback)
        set_event_callback(conf, "vc.meeting.leave_meeting_v1",
                          handler.handle, clazz=MeetingLeaveMeetingEvent)


class MeetingMeetingEndedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingMeetingEndedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingMeetingEndedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingMeetingEndedEvent], Any]) -> None
        handler = MeetingMeetingEndedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.meeting_ended_v1",
                          handler.handle, clazz=MeetingMeetingEndedEvent)


class MeetingMeetingStartedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingMeetingStartedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingMeetingStartedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingMeetingStartedEvent], Any]) -> None
        handler = MeetingMeetingStartedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.meeting_started_v1",
                          handler.handle, clazz=MeetingMeetingStartedEvent)


class MeetingRecordingEndedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingRecordingEndedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingRecordingEndedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingRecordingEndedEvent], Any]) -> None
        handler = MeetingRecordingEndedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.recording_ended_v1",
                          handler.handle, clazz=MeetingRecordingEndedEvent)


class MeetingShareEndedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingShareEndedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingShareEndedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingShareEndedEvent], Any]) -> None
        handler = MeetingShareEndedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.share_ended_v1",
                          handler.handle, clazz=MeetingShareEndedEvent)


class MeetingJoinMeetingEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingJoinMeetingEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingJoinMeetingEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingJoinMeetingEvent], Any]) -> None
        handler = MeetingJoinMeetingEventHandler(callback)
        set_event_callback(conf, "vc.meeting.join_meeting_v1",
                          handler.handle, clazz=MeetingJoinMeetingEvent)


class MeetingRecordingStartedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingRecordingStartedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingRecordingStartedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingRecordingStartedEvent], Any]) -> None
        handler = MeetingRecordingStartedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.recording_started_v1",
                          handler.handle, clazz=MeetingRecordingStartedEvent)


class MeetingSendMeetingImEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingSendMeetingImEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingSendMeetingImEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingSendMeetingImEvent], Any]) -> None
        handler = MeetingSendMeetingImEventHandler(callback)
        set_event_callback(conf, "vc.meeting.send_meeting_im_v1",
                          handler.handle, clazz=MeetingSendMeetingImEvent)


class MeetingShareStartedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingShareStartedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingShareStartedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingShareStartedEvent], Any]) -> None
        handler = MeetingShareStartedEventHandler(callback)
        set_event_callback(conf, "vc.meeting.share_started_v1",
                          handler.handle, clazz=MeetingShareStartedEvent)


class MeetingRecordingReadyEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, MeetingRecordingReadyEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, MeetingRecordingReadyEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, MeetingRecordingReadyEvent], Any]) -> None
        handler = MeetingRecordingReadyEventHandler(callback)
        set_event_callback(conf, "vc.meeting.recording_ready_v1",
                          handler.handle, clazz=MeetingRecordingReadyEvent)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.files = FileService(self)
        self.folders = FolderService(self)
        



class FileService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def copy(self, body, user_access_token=None, timeout=None):
        # type: (FileCopyReqBody, str, int) -> FileCopyReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FileCopyReqCall(self, body, request_opts=request_opts)

    def create(self, body, user_access_token=None, timeout=None):
        # type: (FileCreateReqBody, str, int) -> FileCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FileCreateReqCall(self, body, request_opts=request_opts)

    def docs_delete(self, user_access_token=None, timeout=None):
        # type: (str, int) -> FileDocsDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FileDocsDeleteReqCall(self, request_opts=request_opts)

    def spreadsheets_delete(self, user_access_token=None, timeout=None):
        # type: (str, int) -> FileSpreadsheetsDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FileSpreadsheetsDeleteReqCall(self, request_opts=request_opts)


class FolderService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def children(self, user_access_token=None, timeout=None):
        # type: (str, int) -> FolderChildrenReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FolderChildrenReqCall(self, request_opts=request_opts)

    def create(self, body, user_access_token=None, timeout=None):
        # type: (FolderCreateReqBody, str, int) -> FolderCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FolderCreateReqCall(self, body, request_opts=request_opts)

    def meta(self, user_access_token=None, timeout=None):
        # type: (str, int) -> FolderMetaReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FolderMetaReqCall(self, request_opts=request_opts)

    def root_meta(self, user_access_token=None, timeout=None):
        # type: (str, int) -> FolderRootMetaReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return FolderRootMetaReqCall(self, request_opts=request_opts)



class FolderChildrenReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FolderService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_folderToken(self, folder_token):
        # type: (str) -> FolderChildrenReqCall
        self.path_params['folderToken'] = folder_token
        return self

    def set_types(self, types):
        # type: (List[str]) -> FolderChildrenReqCall
        self.query_params['types'] = types
        return self

    def do(self):
        # type: () -> Response[FolderChildrenResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('drive/explorer/v2/folder/:folderToken/children', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=FolderChildrenResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FileCopyReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (FileService, FileCopyReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_fileToken(self, file_token):
        # type: (str) -> FileCopyReqCall
        self.path_params['fileToken'] = file_token
        return self

    def do(self):
        # type: () -> Response[FileCopyResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/file/copy/files/:fileToken', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=FileCopyResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FileCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (FileService, FileCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_folderToken(self, folder_token):
        # type: (str) -> FileCreateReqCall
        self.path_params['folderToken'] = folder_token
        return self

    def do(self):
        # type: () -> Response[FileCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/file/:folderToken', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=FileCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FolderCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (FolderService, FolderCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_folderToken(self, folder_token):
        # type: (str) -> FolderCreateReqCall
        self.path_params['folderToken'] = folder_token
        return self

    def do(self):
        # type: () -> Response[FolderCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/folder/:folderToken', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=FolderCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FileDocsDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FileService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_docToken(self, doc_token):
        # type: (str) -> FileDocsDeleteReqCall
        self.path_params['docToken'] = doc_token
        return self

    def do(self):
        # type: () -> Response[FileDocsDeleteResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/file/docs/:docToken', 'DELETE', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=FileDocsDeleteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FolderMetaReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FolderService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_folderToken(self, folder_token):
        # type: (str) -> FolderMetaReqCall
        self.path_params['folderToken'] = folder_token
        return self

    def do(self):
        # type: () -> Response[FolderMetaResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/folder/:folderToken/meta', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=FolderMetaResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FolderRootMetaReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FolderService, List[Any]) -> None

        self.service = service
        

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[FolderRootMetaResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('drive/explorer/v2/root_folder/meta', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=FolderRootMetaResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FileSpreadsheetsDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FileService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_spreadsheetToken(self, spreadsheet_token):
        # type: (str) -> FileSpreadsheetsDeleteReqCall
        self.path_params['spreadsheetToken'] = spreadsheet_token
        return self

    def do(self):
        # type: () -> Response[FileSpreadsheetsDeleteResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('drive/explorer/v2/file/spreadsheets/:spreadsheetToken', 'DELETE', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=FileSpreadsheetsDeleteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp

